﻿Imports rskibbe.Ini.Contracts
Imports rskibbe.Ini.Models

Public Class Form1

    Public Const ConfigFilePath As String = ".\config.ini"

    Public Property Config As IIniFile

    Private Async Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        Await LoadSettingsAsync()
    End Sub

    Private Async Function LoadSettingsAsync() As Task
        Try
            If IO.File.Exists(ConfigFilePath) Then
                Config = Await IniFile.LoadAsync(ConfigFilePath)
            Else
                Await IO.File.WriteAllTextAsync(ConfigFilePath, String.Empty)
                Config = New IniFile(ConfigFilePath)
            End If
        Catch ex As Exception
            MessageBox.Show($"Error loading config: `{ex.Message}`")
        End Try
        tbDbHost.Text = Config.GetString("Db", "Host")
        tbDbDb.Text = Config.GetString("Db", "Name")
        tbDbUser.Text = Config.GetString("Db", "User")
        tbDbPassword.Text = Config.GetString("Db", "Password")
        nudDbPort.Value = Config.GetDecimal("Db", "Port", 3306)
    End Function

    Private Async Sub btnSave_Click(sender As Object, e As EventArgs) Handles btnSave.Click
        If Not CheckData() Then
            Return
        End If
        Await SaveDataAsync()
    End Sub

    Private Function CheckData() As Boolean
        If tbDbHost.Text = "" Then
            MessageBox.Show("Please provide the DB host")
            Return False
        End If
        If tbDbDb.Text = "" Then
            MessageBox.Show("Please provide the DB name")
            Return False
        End If
        If tbDbUser.Text = "" Then
            MessageBox.Show("Please provide the DB user")
            Return False
        End If
        If tbDbPassword.Text = "" Then
            MessageBox.Show("Please provide the DB password")
            Return False
        End If
        Return True
    End Function

    Private Async Function SaveDataAsync() As Task
        Config.SetString("Db", "Host", tbDbHost.Text)
        Config.SetString("Db", "Name", tbDbDb.Text)
        Config.SetString("Db", "User", tbDbUser.Text)
        ' in a real world scenario you should at least
        ' encode / decode the password
        ' don't store it in clear form
        Config.SetString("Db", "Password", tbDbPassword.Text)
        Config.SetInt("Db", "Port", Convert.ToInt32(nudDbPort.Value))

        Dim nl = Environment.NewLine
        Try
            Await Config.SaveAsync() _
                .ConfigureAwait(False)
            MessageBox.Show($"Config file `{Config.FilePath}` has been saved")
        Catch ex As Exception
            MessageBox.Show($"Error saving config file `{Config.FilePath}`:{nl}{nl}{ex.Message}")
        End Try
    End Function

End Class
